==> gwt-material-1.4.1.jar: gwt/material/design/client/ui/MaterialIntegerBox.java <==
package gwt.material.design.client.ui;

/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

//@formatter:off

/**
 * Material Integer Box is an input field that accepts any Integer based string
 * from user. <h3>UiBinder Usage:</h3>
 * 
 * <pre>
 * {@code <m:MaterialIntegerBox placeholder="Your integer" step=100/>}
 * </pre>
 * 
 * The parsing and formatting of the number are done natively by the browser,
 * using the i18n settings from the user.
 * 
 * @see <a href="http://gwt-material-demo.herokuapp.com/#forms">Material
 *      IntegerBox</a>
 * @author paulux84
 */
// @formatter:on
public class MaterialIntegerBox extends MaterialNumberBox<Integer> {

    public MaterialIntegerBox() {
        setStep("1");
    }

    @Override
    public Integer getValue() {
        double number = getValueAsNumber();
        if (Double.isNaN(number)) {
            return null;
        }
        return (int) Math.rint(number);
    }

}

==> gwt-material-2.0-rc6.jar: gwt/material/design/client/ui/MaterialIntegerBox.java <==
/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 - 2017 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package gwt.material.design.client.ui;

//@formatter:off

/**
 * Material Integer Box is an input field that accepts any Integer based string
 * from user. <h3>UiBinder Usage:</h3>
 * <p>
 * <pre> {@code <m:MaterialIntegerBox ui:field="txtIntegerBox" label="Integer value"/>
 *
 * // Setting value in Java
 * txtIntegerBox.setValue(10);
 * }
 * </pre>
 * <p>
 * The parsing and formatting of the number are done natively by the browser,
 * using the i18n settings from the user.
 *
 * @author paulux84
 * @see <a href="http://gwtmaterialdesign.github.io/gwt-material-demo/#forms">Material
 * IntegerBox</a>
 * @see <a href="https://material.io/guidelines/components/text-fields.html#">Material Design Specification</a>
 */
// @formatter:on
public class MaterialIntegerBox extends MaterialNumberBox<Integer> {

    public MaterialIntegerBox() {
        setStep("1");
    }

    public MaterialIntegerBox(String placeholder) {
        this();
        setPlaceholder(placeholder);
    }

    public MaterialIntegerBox(String placeholder, int value) {
        this(placeholder);
        setValue(value);
    }

    @Override
    protected Integer parseNumber(double number) {
        if (Double.isNaN(number)) {
            return null;
        }
        return (int) Math.rint(number);
    }
}
